# Icarus Api

_用以提供开发时的补全提示_
## 0.1.7
- utils
  - 修复颜色故障
- net
  - Proxy()创建一个代理 (Beta)
  - request()增加一个新的参数timeout用以控制连接超时
## 0.1.6
- strings
  - extend()扩展字符串
- net
  - SFTP()连接sftp
- ICARUS
  - config()
  - exit() 现在可以自由终止py运行
  - terminal_size() 获取终端尺寸
- utils
  - fuzzy_match()
  - fuzzy_search()
  - center() 居中输出
  - echo()现在支持更复杂的颜色参数，并支持windows CMD。（向下兼容）
  - walk_dir()现在支持递归遍历（向下兼容）

## 0.1.5
- ICARUS
  - shell_exec()增加新参数back，表示是否在后台执行。
  - 删除argv() 获取参数请通过sys.argv[]
## 0.1.4
- coding
  - json_indent()
  - url_encode()
  - url_decode()
- 新增strings模块
  - replace
  - match从utils移至strings
- utils
  - now()

## 0.1.3
- utils
  - ProgressBar
  - format()
- files
  - save_excel()
- load更名files

## 0.1.2
- load
  - load_excel()


## 0.1.1
- utils
  - input() 输入
  - search() 搜索
  - exec_js(),exec_js_file()
  - walkdir更名为walk_dir
- ICARUS
  - platform() 获取操作系统类型
- coding
  - 增加json_loads(),json_dumps()
- cmds
  - REVERSE_SHELL() 生成反弹shell命令
  - NC_LISTEN() 生成netcat监听命令

## 0.1.0
- ICARUS
  - 调整了shell_exec的参数
- utils
  - 增加read_file,save_file
- net
  - 增加ssh,ssh_exec,ssh_run
  - 增加TCP类，连接后可进行收发操作
- cmds
  - 新增cmds包，用于生成常见命令
  - PUT_PUBLIC_KEY() 生成写入公钥命令
## 0.0.9
- utils
  - 增加notice 调用系统通知 _(toast)_
- net
  - 完善net包提示
##0.0.8
- net
  - 增加request

##0.0.7
- utils
  - 增加walkdir，unzip
- net
  - 增加download

##0.0.6
- ICARUS
  - 增加shell_fetch，kill_task

## 0.0.5
整理api格式

## 0.0.4
- fofa
- coding
- vault


## 0.0.3
- docker

## 0.0.2
- utils.color

## 0.0.1
- ICARUS
- utils